import io
import os

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

LONG_DESC_PATH = os.path.join(os.path.dirname(__file__), "README.md")
LONG_DESC = io.open(LONG_DESC_PATH, encoding="utf-8").read()

setup(
    name="ghp-import",
    version="1.0.0",
    description="Copy your docs directly to the gh-pages branch.",
    long_description=LONG_DESC,
    long_description_content_type='text/markdown',
    author="Paul Joseph Davis",
    author_email="paul.joseph.davis@gmail.com",
    license="Apache Software License",
    url="http://github.com/davisp/ghp-import",
    zip_safe=False,

    install_requires=[
        "python-dateutil>=2.8.1",
    ],

    extras_require={
        'dev': [
            'twine',
            'markdown',
            'flake8',
        ],
    },

    classifiers=[
        "Development Status :: 3 - Alpha",
        "License :: OSI Approved :: Apache Software License",
        "Intended Audience :: Developers",
        'Natural Language :: English',
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 3",
    ],

    py_modules=["ghp_import"],

    entry_points={
        "console_scripts": [
            "ghp-import = ghp_import:main",
        ],
    }
)
